@@ -13,7 +13,7 @@ use 5.00800;
 use Carp 'croak';
 use Scalar::Util;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(encoded_string build_mt render_mt);
 our %EXPORT_TAGS = (
@@ -90,7 +90,7 @@ sub _build {
     # Compile
     my @lines;
     my $last_was_code;
-    my $last_text;
+    my $cached_text;
     for my $line (@{$self->{tree}}) {
 
         # New line
@@ -99,9 +99,9 @@ sub _build {
             my $type  = $line->[$j];
             my $value = $line->[$j + 1];
 
-            if ($type ne 'text' && defined $last_text) {
-                $lines[-1] = "\$_MT .=\"$last_text\";";
-                undef $last_text;
+            if ($type ne 'text' && defined $cached_text) {
+                $lines[-1] = "\$_MT .=\"$cached_text\";";
+                undef $cached_text;
             }
             
             # Need to fix line ending?
@@ -120,7 +120,12 @@ sub _build {
                 $value = quotemeta($value);
                 $value .= '\n' if $newline;
 
-                $last_text = defined $last_text ? "$last_text$value" : $value;
+                if ($lines[-1] eq '') {
+                    $cached_text =
+                        defined $cached_text ? "$cached_text$value" : $value;
+                } else {
+                    $lines[-1] .= "\$_MT.=\"$value\";";
+                }
             }
 
             # Code
@@ -142,8 +147,8 @@ sub _build {
         $lines[-1] .= "\n;";
     }
     # add last text line(s)
-    if (defined $last_text) {
-        $lines[-1] .= "\$_MT .=\"$last_text\";";
+    if (defined $cached_text) {
+        $lines[-1] .= "\$_MT .=\"$cached_text\";";
     }
     
     # Wrap
